#[non_exhaustive]pub enum ModelError {
NoObjective,
InvalidInput(String),
SolveError(SolveError),
Timeout,
NonConvex(String),
NotSupported(String),
Internal(String),
}Expand description
Errors that can occur when building or solving a Model.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoObjective
solve() was called before minimize() or maximize().
InvalidInput(String)
A modeling API input was invalid.
SolveError(SolveError)
The solver returned a non-optimal status.
Timeout
Solver timed out before finding an optimal solution.
NonConvex(String)
Problem has a non-convex (indefinite) objective; global optimality cannot
be guaranteed via IPM. Use solve_qp_global for non-convex continuous QP.
NotSupported(String)
Problem type is not supported by this solver (e.g. QCQP).
Internal(String)
An unexpected internal error (bug or invariant violation).