#[non_exhaustive]pub enum SolutionProof {
GlobalOptimal,
LocalOptimal,
FeasibleUnproven,
}Expand description
What kind of optimality proof backs a successful ModelResult.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
GlobalOptimal
A global optimum was proven.
LocalOptimal
A local KKT point was returned without a global proof.
FeasibleUnproven
A feasible incumbent is available, but optimality was not proven.